@@ -55,12 +55,12 @@ a clean way of defining Namespaces for XML::Stream to use when connecting.
 =head1 EXAMPLES
 
 
-  $myNamespace = new XML::Stream::Namespace("mynamspace");
+  $myNamespace = XML::Stream::Namespace->new("mynamspace");
   $myNamespace->SetXMLNS("http://www.mynamespace.org/xmlns");
   $myNamespace->SetAttributes(foo=>"bar",
                               bob=>"vila");
 
-  $stream = new XML::Stream;
+  $stream = XML::Stream->new;
   $stream->Connect(name=>"foo.bar.org",
                    port=>1234,
                    namespace=>"foo:bar",
@@ -96,10 +96,11 @@ This module licensed under the LGPL, version 2.1.
 =cut
 
 use strict;
+use warnings;
 use Carp;
 use vars qw( $VERSION );
 
-$VERSION = "1.23_04";
+$VERSION = "1.23_05";
 
 sub new
 {
