@@ -139,9 +139,11 @@ This module licensed under the LGPL, version 2.1.
 
 =cut
 
+use strict;
+use warnings;
 use vars qw( $VERSION $LOADED );
 
-$VERSION = "1.23_04";
+$VERSION = "1.23_05";
 $LOADED = 1;
 
 sub new
@@ -221,7 +223,7 @@ sub add_child
 {
     my $self = shift;
 
-    my $child = new XML::Stream::Node(@_);
+    my $child = XML::Stream::Node->new(@_);
     push(@{$self->{CHILDREN}},$child);
     return $child;
 }
@@ -246,7 +248,7 @@ sub remove_child
 sub add_cdata
 {
     my $self = shift;
-    my $child = new XML::Stream::Node("__xmlstream__:node:cdata");
+    my $child = XML::Stream::Node->new("__xmlstream__:node:cdata");
     foreach my $cdata (@_)
     {
         push(@{$child->{CHILDREN}},$cdata);
@@ -401,7 +403,7 @@ sub copy
 {
     my $self = shift;
 
-    my $new_node = new XML::Stream::Node();
+    my $new_node = XML::Stream::Node->new();
     $new_node->set_tag($self->get_tag());
     $new_node->put_attrib($self->attrib());
 
@@ -442,7 +444,7 @@ sub _handle_element
 
     $self->debug(2,"Node: _handle_element: sid($sid) sax($sax) tag($tag) att(",%att,")");
 
-    my $node = new XML::Stream::Node($tag);
+    my $node = XML::Stream::Node->new($tag);
     $node->put_attrib(%att);
 
     $self->debug(2,"Node: _handle_element: check(",$#{$self->{SIDS}->{$sid}->{node}},")");
