@@ -55,9 +55,10 @@ This module licensed under the LGPL, version 2.1.
 =cut
 
 use strict;
+use warnings;
 use vars qw( $VERSION );
 
-$VERSION = "1.23_04";
+$VERSION = "1.23_05";
 
 use XML::Stream::Tree;
 use XML::Stream::Node;
@@ -103,7 +104,7 @@ sub new
         $self->{DEBUG} = 1;
         if (lc($args{debug}) eq "stdout")
         {
-            $self->{DEBUGFILE} = new FileHandle(">&STDERR");
+            $self->{DEBUGFILE} = FileHandle->new(">&STDERR");
             $self->{DEBUGFILE}->autoflush(1);
         }
         else
@@ -112,7 +113,7 @@ sub new
             {
                 if (-w $args{debug})
                 {
-                    $self->{DEBUGFILE} = new FileHandle(">$args{debug}");
+                    $self->{DEBUGFILE} = FileHandle->new(">$args{debug}");
                     $self->{DEBUGFILE}->autoflush(1);
                 }
                 else
@@ -124,7 +125,7 @@ sub new
             }
             else
             {
-                $self->{DEBUGFILE} = new FileHandle(">$args{debug}");
+                $self->{DEBUGFILE} = FileHandle->new(">$args{debug}");
                 if (defined($self->{DEBUGFILE}))
                 {
                     $self->{DEBUGFILE}->autoflush(1);
